@@ -43,6 +43,25 @@ class BronoteAction(ABC):
         """Process the action."""
         pass
 
+    def set_attributes(self, args):
+        """Set attributes based on arguments and flags.
+
+        Parameters:
+            args: Arguments given from CLI
+        """
+        for flag in self.flags.keys():
+            flagname = flag[2:]
+            try:
+                setattr(self, flagname, getattr(args, flagname))
+            except AttributeError:
+                setattr(self, flagname, None)
+
+        for argument in self.arguments.keys():
+            try:
+                setattr(self, argument, getattr(args, argument))
+            except AttributeError:
+                setattr(self, argument, None)
+
     def add_arguments(self, subparser):
         """Add an actions arguments to a subparser."""
         for argument in self.arguments.keys():
@@ -53,7 +72,7 @@ class BronoteAction(ABC):
                 help=argdict['help'],
                 nargs=argdict['nargs']
             ).complete = {
-                "zsh": f"_files -W {self.cfg.dir}",
+                "zsh": f"_files -W {self.cfg.notes_dir}",
             }
 
     def add_flags(self, subparser):
@@ -80,7 +99,7 @@ class BronoteAction(ABC):
     def sync(self):
         """Sync with git."""
         try:
-            repo = Repo(self.cfg.dir)
+            repo = Repo(self.cfg.notes_dir)
         except InvalidGitRepositoryError:
             return 'Not a git repo. Set one up first, use the git \
 action to execute git commands in your notes directory and set things up. \
@@ -118,7 +137,7 @@ Auto-syncing can be enable through the set action.'
 
     def find_note(self, filename):
         """Find first occurance of a note traversing from the base folder."""
-        for node in os.walk(self.cfg.dir):
+        for node in os.walk(self.cfg.notes_dir):
             (basepath, dirs, files) = node
 
             for file in files:
